import {
  select, 
  geoPath, 
  geoMercator, 
  geoOrthographic,
  geoStereographic,
  geoEqualEarth,
  geoEqualEarthRaw,
  geoAlbersUsa,
  zoom,
  event,
  scaleOrdinal,
  schemeCategory10,
  schemeSpectral,
} from 'd3';

import { colorLegend } from './colorLegend.js'

import {loadAndProcessData} from './loadAndProcessData.js';

const svg = select('svg');
// svg.style('background-color', 'red'); test

const height = +svg.attr('height');
//+ equals paresFloat()
const width = +svg.attr('width');

const projection = geoEqualEarth();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');


const colorLegendG = svg.append('g')
  .attr('transform', `translate(30 ,300)`);

svg.call(zoom()
	.on('zoom',() => {
	g.attr('transform',event.transform);
}));

g.append('path')
	.attr('class', 'sphere')
	.attr('d', pathGenerator({type:"Sphere"}));

//原视频中使用tsv文件，但是我使用的文件里面是有国家名字的，所以不需要tsv文件

let colorSet = ['#eb2617', '#ffaa00', '#4dff00', '#00fbff', '#bb00ff', '#eeff00'];

const createGetColor = (idx)=>{
  var i = idx || -1;
  return {
    get : () => {i=(i+1)%colorSet.length; return colorSet[i];}
  };
};

const getColor = createGetColor();

loadAndProcessData().then(countries => {
  const colorValue = d => d.properties.economy
  
  const colorScale = scaleOrdinal()
  	.domain(countries.features.map(colorValue));
  colorScale
    .domain(colorScale.domain().sort().reverse())
  	.range(schemeSpectral[colorScale.domain().length]);
  
	//search d3-scale-chromatic 找到好看的颜色

  const onClick = d => {
  	console.log(d);
  }
  colorLegendG.call(colorLegend, {
    colorScale,
    circleRadius: 8,
    spacing : 20,
    textOffset : 15,
    backgroundRectWidth: 250,
    onClick
  });


  g.selectAll('path').data(countries.features)
    .enter().append('path')
    .attr('class', 'country')
    .attr('fill', d => colorScale(colorValue(d))) 
    .attr('d', pathGenerator)
  .append('title')//